@@ -30,6 +30,7 @@ class PollRemoteManager(PollsRemoteManager):
         kwargs['extra_fields'] = {'post_id': post.id}
         kwargs['poll_id'] = poll_id
         kwargs['owner_id'] = owner.remote_id
+        # TODO: make all group remote_id negative
         if isinstance(owner, Group):
              kwargs['owner_id'] *= -1
         return super(PollRemoteManager, self).fetch(**kwargs)
@@ -102,6 +103,7 @@ class Poll(PollsAbstractModel):
         for answer in self._answers:
             answer.poll = self
             answer.save()
+        self._answers = []
 
         return result
 
@@ -121,6 +123,9 @@ class Answer(PollsAbstractModel):
     objects = AnswerManager()
     remote = AnswerRemoteManager()
 
+    def __unicode__(self):
+        return self.text
+
     def parse(self, response):
         response['votes_count'] = response.pop('votes')
 
@@ -174,4 +179,6 @@ class Answer(PollsAbstractModel):
         if len(items) == number_on_page:
             return self.fetch_voters(offset=offset+number_on_page)
         else:
-            return self.voters.all()
\ No newline at end of file
+            return self.voters.all()
+
+import signals
\ No newline at end of file
